from datetime import date

from django.test import TestCase, RequestFactory
from django.contrib.auth.models import User, AnonymousUser

from molo.profiles.context_processors import get_profile_data
from molo.core.tests.base import MoloTestCaseMixin


class ContextProcessorsTest(TestCase, MoloTestCaseMixin):

    def setUp(self):
        self.mk_main()
        self.factory = RequestFactory()
        self.user = User.objects.create_user(
            username='tester',
            email='tester@example.com',
            password='tester')

    def test_get_profile_data_authenticated_anonymous(self):
        request = self.factory.get('/')
        request.user = self.user
        context = get_profile_data(request)
        self.assertEqual(context['username'], 'tester')
        self.assertEqual(context['alias'], 'Anonymous')

    def test_get_profile_data_authenticated_alias(self):
        profile = self.user.profile
        profile.alias = 'The Alias'
        profile.save()
        request = self.factory.get('/')
        request.user = self.user
        context = get_profile_data(request)
        self.assertEqual(context['alias'], 'The Alias')

    def test_get_profile_data_authenticated_dob(self):
        profile = self.user.profile
        profile.date_of_birth = date(1980, 1, 1)
        profile.save()
        request = self.factory.get('/')
        request.user = self.user
        context = get_profile_data(request)
        self.assertEqual(context['date_of_birth'], date(1980, 1, 1))

    def test_get_profile_data_unauthenticated(self):
        request = self.factory.get('/')
        request.user = AnonymousUser()
        context = get_profile_data(request)
        self.assertEqual(context['username'], '')
        self.assertEqual(context['date_of_birth'], '')
        self.assertEqual(context['alias'], '')



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


def create_reaction_question_index(apps, schema_editor):
    from molo.core.models import ReactionQuestionIndexPage, Main
    main = Main.objects.all().first()

    if main:
        reaction_question_index = ReactionQuestionIndexPage(
            title='Reaction Questions', slug='reaction-questions')
        main.add_child(instance=reaction_question_index)
        reaction_question_index.save_revision().publish()


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0059_reaction_questions'),
    ]

    operations = [
        migrations.RunPython(create_reaction_question_index),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.10 on 2016-10-24 10:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0010_create_security_question_index_page'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofilessettings',
            name='country_code',
            field=models.CharField(blank=True, help_text='For example: +27 for South Africa, +44 for England', max_length=4, null=True, verbose_name="The country code that should be added to a user's number for this site"),
        ),
    ]



# -*- coding: UTF-8 -*-
import csv
import pytz
import tempfile
from datetime import datetime
from django.core.management import call_command
from django.test import TestCase
from django.utils.six import StringIO
from molo.core.tests.base import MoloTestCaseMixin
from molo.core.models import (
    Main, Languages, ArticlePage, Tag, ArticlePageTags, SiteLanguageRelation,
    SiteLanguage, LanguageRelation, SectionPage, PageTranslation)


class ManagementCommandsTest(TestCase, MoloTestCaseMixin):
    def setUp(self):
        self.mk_main()
        self.main = Main.objects.all().first()
        self.language_setting = Languages.objects.create(
            site_id=self.main.get_site().pk)
        self.english = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(self.main.get_site()),
            locale='en',
            is_active=True)
        self.spanish = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(self.main.get_site()),
            locale='sp',
            is_active=True)
        self.french = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(self.main.get_site()),
            locale='fr',
            is_active=True)
        self.yourmind = self.mk_section(
            self.section_index, title='Your mind')
        self.article = ArticlePage(title='Test Article', slug='test-article')
        self.yourmind.add_child(instance=self.article)
        self.article.save_revision().publish()

    def test_switch_main_language(self):
        out = StringIO()
        tag = Tag(title='love', slug='love')
        self.tag_index.add_child(instance=tag)
        tag.save_revision().publish()
        for relation in LanguageRelation.objects.filter(
                language__is_main_language=True):
            self.assertEqual(relation.language.locale, 'en')
        self.assertTrue(self.english.is_main_language)
        call_command('switch_main_language', 'id', std_out=out)
        self.assertTrue(SiteLanguage.objects.get(locale='id').is_main_language)
        self.assertFalse(
            LanguageRelation.objects.filter(language__locale='en').exists())
        for relation in LanguageRelation.objects.filter(
                language__is_main_language=True):
            self.assertEqual(relation.language.locale, 'id')

    def test_add_language_to_pages(self):
        call_command('add_language_to_pages')
        english = SiteLanguage.objects.first()
        article = ArticlePage.objects.get(pk=self.article.pk)
        yourmind = SectionPage.objects.get(pk=self.yourmind.pk)
        self.assertEquals(article.language, english)
        self.assertEquals(yourmind.language, english)

    def test_add_translated_pages_to_pages(self):
        self.mk_main2()
        self.main2 = Main.objects.all().last()
        self.language_setting2 = Languages.objects.create(
            site_id=self.main2.get_site().pk)
        self.english2 = SiteLanguageRelation.objects.create(
            language_setting=self.language_setting2,
            locale='en',
            is_active=True)

        self.spanish2 = SiteLanguageRelation.objects.create(
            language_setting=self.language_setting2,
            locale='es',
            is_active=True)
        self.yourmind2 = self.mk_section(
            self.section_index2, title='Your mind')
        # create article in english with translation in spanish and french
        english_article = self.article
        spanish_article = self.mk_article_translation(
            english_article, self.spanish)
        french_article = self.mk_article_translation(
            english_article, self.french)
        PageTranslation.objects.create(
            page=english_article, translated_page=english_article)

        # create section in english with translations
        english_section = self.yourmind
        english_section2 = self.yourmind2
        spanish_section = self.mk_section_translation(
            self.yourmind, self.spanish)
        spanish_section2 = self.mk_section_translation(
            self.yourmind2, self.spanish2)
        french_section = self.mk_section_translation(
            self.yourmind, self.french)

        # need to delete it here since it gets added in base
        for article in ArticlePage.objects.all():
            article.translated_pages.clear()
            article.save()
        for section in SectionPage.objects.all():
            section.translated_pages.clear()
            section.save()
        self.assertFalse(english_article.translated_pages.exists())
        self.assertFalse(spanish_article.translated_pages.exists())
        self.assertFalse(french_article.translated_pages.exists())
        self.assertFalse(english_section.translated_pages.exists())
        self.assertFalse(english_section2.translated_pages.exists())
        self.assertFalse(spanish_section.translated_pages.exists())
        self.assertFalse(spanish_section2.translated_pages.exists())
        self.assertFalse(french_section.translated_pages.exists())

        # run command to add languages to these pages
        call_command('add_language_to_pages')

        # run command to add list of translated_pages to these pages
        call_command('add_translated_pages_to_pages')

        # test translated pages for articles
        self.assertTrue(english_article.translated_pages.filter(
            pk=spanish_article.pk).exists())
        self.assertTrue(english_article.translated_pages.filter(
            pk=french_article.pk).exists())
        self.assertFalse(english_article.translated_pages.filter(
            pk=english_article.pk).exists())
        self.assertTrue(spanish_article.translated_pages.filter(
            pk=english_article.pk).exists())
        self.assertTrue(spanish_article.translated_pages.filter(
            pk=french_article.pk).exists())
        self.assertFalse(spanish_article.translated_pages.filter(
            pk=spanish_article.pk).exists())
        self.assertTrue(french_article.translated_pages.filter(
            pk=english_article.pk).exists())
        self.assertTrue(french_article.translated_pages.filter(
            pk=spanish_article.pk).exists())

        # test translated pages for sections
        self.assertTrue(english_section.translated_pages.filter(
            pk=spanish_section.pk).exists())
        self.assertTrue(english_section2.translated_pages.filter(
            pk=spanish_section2.pk).exists())
        self.assertTrue(english_section.translated_pages.filter(
            pk=french_section.pk).exists())
        self.assertTrue(spanish_section.translated_pages.filter(
            pk=english_section.pk).exists())
        self.assertTrue(spanish_section2.translated_pages.filter(
            pk=english_section2.pk).exists())
        self.assertTrue(spanish_section.translated_pages.filter(
            pk=french_section.pk).exists())
        self.assertTrue(french_section.translated_pages.filter(
            pk=english_section.pk).exists())
        self.assertTrue(french_section.translated_pages.filter(
            pk=spanish_section.pk).exists())

    def test_add_feature_in_latest_date_to_article(self):
        self.assertEquals(self.article.featured_in_latest_start_date, None)
        now = datetime.now()
        now = pytz.utc.localize(now)

        # create the csv file with the article slug and date
        data = {
            self.article.slug: now
        }
        fake_namefile = tempfile.NamedTemporaryFile()
        with open(fake_namefile.name, 'w') as fake_csv:
            writer = csv.writer(fake_csv)
            writer.writerow(['slug', 'date'])
            for key, value in data.items():
                writer.writerow([key, value])
        # call the command
        out = StringIO()
        call_command(
            'set_promotional_dates_from_csv', fake_namefile.name, std_out=out)
        self.assertEquals(
            ArticlePage.objects.last().featured_in_latest_start_date, now)
        fake_namefile.close()

    def test_add_tag_to_article(self):
        self.assertEquals(ArticlePageTags.objects.count(), 0)
        # create the tag data
        tag = Tag(title='over 18', slug='over-18')
        self.tag_index.add_child(instance=tag)
        tag.save_revision().publish()
        tag_data = {
            self.article.slug: tag.title
        }

        # create csv
        fake_namefile = tempfile.NamedTemporaryFile()
        with open(fake_namefile.name, 'w') as fake_csv:
            writer = csv.writer(fake_csv)
            writer.writerow(['slug', 'date'])
            for key, value in tag_data.items():
                writer.writerow([key, value])

        # call command to link tag to article
        out = StringIO()
        call_command(
            'add_tag_to_article', fake_csv.name, 'en',
            std_out=out)

        # it should create a Article Relationship with the Tag
        self.assertEquals(ArticlePageTags.objects.count(), 1)
        self.assertEquals(
            ArticlePageTags.objects.first().tag.title, tag.title)
        self.assertEquals(
            ArticlePageTags.objects.first().page, self.article)

        fake_namefile.close()



COMMENTING_OPEN = 'O'
COMMENTING_CLOSED = 'C'
COMMENTING_DISABLED = 'D'
COMMENTING_TIMESTAMPED = 'T'

COMMENTING_STATE_CHOICES = (
    (COMMENTING_OPEN, 'Open'),
    (COMMENTING_CLOSED, 'Closed'),
    (COMMENTING_DISABLED, 'Disabled'),
    (COMMENTING_TIMESTAMPED, 'Timestamped'),
)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.9 on 2018-01-22 10:20
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0040_page_draft_title'),
        ('core', '0076_create_cmssettings'),
    ]

    operations = [
        migrations.CreateModel(
            name='MoloPage',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
            },
            bases=('wagtailcore.page',),
        ),
    ]



import pytest

from datetime import datetime

from django.core.urlresolvers import reverse
from django.test import TestCase

from wagtail.wagtailcore.models import Site

from molo.core.tests.base import MoloTestCaseMixin
from molo.core.models import SectionPage, SiteSettings, \
    ArticlePage, Main, SiteLanguageRelation, Languages, ArticlePageTags
from molo.core.tasks import promote_articles


@pytest.mark.django_db
class TestTranslations(TestCase, MoloTestCaseMixin):
    def setUp(self):
        self.mk_main()
        main = Main.objects.all().first()
        self.english = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(main.get_site()),
            locale='en',
            is_active=True)
        self.french = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(main.get_site()),
            locale='fr',
            is_active=True)
        self.spanish_mexico = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(main.get_site()),
            locale='es-mx',
            is_active=True)

        # Creates a section under the main page
        self.english_section = self.mk_section(
            self.section_index, title='English section')
        # Creates a sub-section under the section
        self.english_subsection = self.mk_section(
            self.english_section, title='English subsection')

        # Login
        self.user = self.login()

    def test_section_index_page(self):
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        self.assertContains(response, 'English section')

    def test_wagtail_root_page_has_no_translations(self):
        response = self.client.get(reverse(
            'wagtailadmin_explore_root'))
        self.assertNotContains(response, 'French')

    def test_that_all_translation_languages_are_listed(self):
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        # Checks main language is not listed as translation language
        self.assertNotContains(response, 'title="English">English')
        # Checks if translation language exists
        self.assertContains(response, 'title="French">French')
        self.assertContains(response,
                            'title="Mexican Spanish">Mexican Spanish')

    def test_that_only_main_language_pages_are_listed(self):
        self.client.post(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        # checks that only the english section is listed
        # and not the french section
        self.assertContains(response, 'English section')
        self.assertNotContains(response,
                               'French translation of English section')

    def test_page_doesnt_have_translation_action_button_links_to_addview(self):
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        self.assertContains(response,
                            '<a href="/admin/translations/add/%s/fr/"'
                            % self.english_section.id)

    def test_that_translation_have_the_right_language(self):
        self.client.get(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))
        page = SectionPage.objects.get(
            title='French translation of English section')
        self.assertEquals(str(page.language.locale), 'fr')

    def test_draft_translations_have_additional_css_clsss(self):
        self.client.post(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))
        page = SectionPage.objects.get(
            slug='french-translation-of-english-section')

        # Ckecks when the translated page is draf
        # the translation button has the right css
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        self.assertContains(
            response, 'class="button button-small button-secondary '
            'translation-translated translation-translated-draft" '
            'title="French">French</a>')

        # Ckecks when the translated page is Draft + live
        # the translation button has the right css
        page.save_revision().publish()
        page.save_revision()
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        self.assertContains(
            response, 'class="button button-small button-secondary '
            'translation-translated translation-translated-draft" '
            'title="French">French</a>')
        # Ckecks when the translated page is Publish
        # the translation button has the right css
        page.save_revision().publish()
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))

        self.assertContains(
            response, 'class="button button-small button-secondary '
            'translation-translated " title="French">French</a>')

    def test_if_page_has_a_translation_the_action_links_to_the_edit_page(self):
        self.client.post(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        page = SectionPage.objects.get(
            slug='french-translation-of-english-section')
        self.assertContains(response,
                            '<a href="/admin/pages/%s/edit/"'
                            % page.id)

    def test_republishing_main_section_effecting_translated_section(self):
        self.client.post(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))
        page = SectionPage.objects.get(
            slug='french-translation-of-english-section')
        page.save_revision().publish()
        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        self.assertContains(
            response, 'class="button button-small button-secondary '
            'translation-translated " title="French">French</a>')

        self.client.post(reverse(
            'wagtailadmin_pages:unpublish', args=[self.english_section.id]))

        self.english_section = SectionPage.objects.get(
            id=self.english_section.id)

        response = self.client.get(reverse(
            'wagtailadmin_explore', args=[self.section_index.id]))
        self.assertContains(
            response, 'class="button button-small button-secondary '
            'translation-translated " title="French">French</a>')

    def test_adding_translation_that_already_exists_redirects_to_edit(self):
        self.client.post(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))

        response = self.client.post(reverse(
            'add_translation', args=[self.english_section.id, 'fr']))
        page = SectionPage.objects.get(
            slug='french-translation-of-english-section')
        self.assertRedirects(
            response, reverse('wagtailadmin_pages:edit', args=[page.id]))

    def test_adding_translation_to_non_translatable_page_redirects_home(self):
        response = self.client.post(reverse(
            'add_translation', args=[self.section_index.id, 'fr']))
        self.assertRedirects(response, reverse('wagtailadmin_home'))

    def test_site_languages_summary(self):
        articles = self.mk_articles(
            parent=self.english_section, count=2)
        for article in articles:
            self.client.post(reverse(
                'add_translation', args=[article.id, 'fr']))
        response = self.client.get(reverse('wagtailadmin_home'))
        self.assertContains(response, '<span>2</span>English Pages')
        self.assertContains(response, '<span>2</span>French Pages')

    def test_site_exists_if_no_iems_translated_for_translated_only(self):
        site_settings = SiteSettings.for_site(self.main.get_site())
        site_settings.enable_tag_navigation = True
        site_settings.show_only_translated_pages = True
        site_settings.save()

        tag = self.mk_tag(parent=self.tag_index)
        tag.feature_in_homepage = True
        tag.save_revision().publish()
        articles = self.mk_articles(
            parent=self.english_section,
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now(), count=30)
        for article in articles:
            ArticlePageTags.objects.create(page=article, tag=tag)

        promote_articles()

        response = self.client.get('/')
        self.assertEquals(response.status_code, 200)
        response = self.client.get('/locale/fr/')
        response = self.client.get('/')
        self.assertEquals(response.status_code, 200)

    def test_that_only_translated_sections_show_with_tag_navigation(self):
        site_settings = SiteSettings.for_site(self.main.get_site())
        site_settings.enable_tag_navigation = True
        site_settings.show_only_translated_pages = True
        site_settings.save()

        self.mk_section_translation(
            self.english_section, self.french,
            title=self.english_section.title + ' in french')

        article1 = self.mk_article(
            self.english_section,
            title='English article1 in English Section',
            featured_in_homepage_start_date=datetime.now(),
            featured_in_homepage=True)
        self.mk_article_translation(
            article1, self.french, title=article1.title + ' in french',)

        promote_articles()

        response = self.client.get('/')
        self.assertContains(response, 'English section')
        response = self.client.get('/locale/fr/')
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section-in-french/"'
            ' class="section-listing__theme-bg-link">'
            'English section in french</a>')

    def test_that_only_translated_pages_are_shown_on_front_end(self):
        # set the site settings show_only_translated_pages to True
        default_site = Site.objects.get(is_default_site=True)
        setting = SiteSettings.objects.create(site=default_site)

        setting.show_only_translated_pages = True
        setting.save()

        eng_section2 = self.mk_section(
            self.section_index, title='English section2')
        self.mk_section_translation(
            eng_section2, self.french,
            title=eng_section2.title + ' in french')

        article1 = self.mk_article(
            eng_section2,
            title='English article1 in section 2',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())
        self.mk_article_translation(
            article1, self.french, title=article1.title + ' in french',)

        article2 = self.mk_article(
            self.english_section,
            title='English article2 in section 1',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())
        self.mk_article_translation(
            article2, self.french, title=article2.title + ' in french',)
        promote_articles()

        # tests that in Home page users will only see the sections
        # that have been translated
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/"'
            ' class="section-listing__theme-bg-link">English section</a>')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2/"'
            ' class="section-listing__theme-bg-link">English section2</a>')
        response = self.client.get('/locale/fr/')
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2-in-french/"'
            ' class="section-listing__theme-bg-link">'
            'English section2 in french</a>')
        self.assertNotContains(
            response,
            '<a href="/sections-main-1/english-section/"'
            ' class="section-listing__theme-bg-link">English section</a>')

        en_page = self.mk_article(self.english_section,
                                  title='English article1',
                                  featured_in_latest_start_date=datetime.now())
        promote_articles()
        en_page = ArticlePage.objects.get(title=en_page.title)
        self.mk_article_translation(
            en_page, self.french, title=en_page.title + ' in french',)

        self.mk_article(self.english_section,
                        title='English article2',
                        featured_in_latest_start_date=datetime.now())
        promote_articles()

        # tests that in english section users will only see the articles
        # that have been translated
        response = self.client.get('/locale/en/')
        response = self.client.get('/sections-main-1/english-section/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/english-article1-3/" '
            'class="promoted-article-list__anchor">'
            '<h3 class="heading promoted-article__title">'
            'English article1'
            '</h3></a>', html=True)
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/english-article2-2/" '
            'class="promoted-article-list__anchor">'
            '<h3 class="heading promoted-article__title">'
            'English article2'
            '</h3></a>', html=True)

        response = self.client.get('/locale/fr/')
        response = self.client.get('/sections-main-1/english-section/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/'
            'english-article1-in-french/" '
            'class="promoted-article-list__anchor">'
            '<h3 class="heading promoted-article__title">'
            'English article1 in french'
            '</h3></a>', html=True)
        self.assertNotContains(
            response,
            '<a href="/sections-main-1/english-section/english-article2-2/" '
            'class="promoted-article-list__anchor">'
            '<h3 class="heading promoted-article__title">'
            'English article2'
            '</h3></a>', html=True)

        # tests that in latest block users will only see the articles
        # that have been translated
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/'
            'english-article1-in-french/" '
            'class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-headings">'
            '<h5 class="heading'
            ' promoted-article__title--theme-headings">'
            'English article1 in french'
            '</h5></a>', html=True)
        self.assertNotContains(
            response,
            '<a href="/sections-main-1/english-section/'
            'english-article1-3/" '
            'class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-headings">'
            '<h5 class="heading'
            ' promoted-article__title--theme-headings">'
            'English article1'
            '</h5></a>', html=True)

        response = self.client.get('/locale/en/')
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/english-article1-3/"'
            ' class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-headings">'
            '<h5 class="heading'
            ' promoted-article__title--theme-headings">English article1</h5>'
            '</a>', html=True)
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/english-article2-2/"'
            ' class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-headings">'
            '<h5 class="heading'
            ' promoted-article__title--theme-headings">English article2</h5>'
            '</a>', html=True)

    def test_that_only_live_pages_show_with_only_translated_setting_off(self):
        # set the site settings show_only_translated_pages to False
        default_site = Site.objects.get(is_default_site=True)
        setting = SiteSettings.objects.create(site=default_site)
        setting.show_only_translated_pages = False
        setting.save()

        self.mk_section_translation(
            self.english_section, self.french,
            title=self.english_section.title + ' in french')

        article1 = self.mk_article(
            self.english_section,
            title='English article1',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())
        self.mk_article_translation(
            article1, self.french, title=article1.title + ' in french',)

        article2 = self.mk_article(
            self.english_section,
            title='English article2',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())

        # tests that users will see the main language article for
        # pages that haven't been translated
        response = self.client.get('/locale/fr/', follow=True)
        response = self.client.get('/sections-main-1/english-section/',
                                   follow=True)
        self.assertContains(
            response, 'English article1 in french', html=True)
        self.assertContains(
            response, 'English article2', html=True)
        self.assertNotContains(
            response, 'English article2 in french', html=True)

        # tests that users won't see the main language page if it isn't live
        article2.unpublish()

        response = self.client.get('/sections-main-1/english-section/',
                                   follow=True)
        self.assertContains(
            response, 'English article1 in french', html=True)
        self.assertNotContains(
            response, 'English article2', html=True)
        self.assertNotContains(
            response, 'English article2 in french', html=True)

        # tests that users won't see the main language page if both it and the
        # the translation are not live
        fr_article = self.mk_article_translation(
            article2, self.french, title=article2.title + ' in french',)
        fr_article.unpublish()

        response = self.client.get('/sections-main-1/english-section/',
                                   follow=True)
        self.assertContains(
            response, 'English article1 in french', html=True)
        self.assertNotContains(
            response, 'English article2', html=True)
        self.assertNotContains(
            response, 'English article2 in french', html=True)

    def test_if_main_lang_page_unpublished_translated_page_still_shows(self):
        eng_section2 = self.mk_section(
            self.section_index, title='English section2')
        self.mk_section_translation(
            eng_section2, self.french,
            title=eng_section2.title + ' in french')
        eng_section2.unpublish()

        self.mk_article(
            eng_section2,
            title='English article1 in section 2',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())

        en_page = self.mk_article(
            self.english_section,
            title='English article1',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())
        promote_articles()
        self.mk_article_translation(
            en_page, self.french, title=en_page.title + ' in french',)

        en_page2 = self.mk_article(
            self.english_section,
            title='English article2',
            featured_in_latest_start_date=datetime.now())
        promote_articles()
        en_page2 = ArticlePage.objects.get(title=en_page2.title)
        self.mk_article_translation(
            en_page2, self.french, title=en_page2.title + ' in french',)
        en_page2.unpublish()

        # tests that on home page users will only
        # see the pages that are published
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/"'
            ' class="section-listing__theme-bg-link">English section</a>')
        self.assertNotContains(
            response,
            '<a href="/sections-main-1/english-section2/"'
            ' class="section-listing__theme-bg-link">English section2</a>')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/english-article1-3/"'
            ' class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-bg">'
            '<h3 class="heading '
            'promoted-article-list__heading">'
            ' English article1</h3></a>',
            html=True)

        self.assertNotContains(
            response,
            '<a href="/sections-main-1/english-section/english-article2-3/"'
            ' class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-bg">'
            '<h3 class="heading'
            ' promoted-article-list__heading">'
            ' English article2</h3></a>',
            html=True)

        response = self.client.get('/sections-main-1/english-section/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/english-article1-3/"'
            ' class="promoted-article-list__anchor">'
            '<h3 class="heading promoted-article__title">'
            'English article1</h3></a>', html=True)
        self.assertNotContains(
            response,
            '<a href="/sections-main-1/english-section/english-article2/"'
            ' class="promoted-article-list__anchor">'
            '<h3 class="heading promoted-article__title">'
            'English article2</h3></a>', html=True)

        # tests that when switching to a child language
        # users will see all the published translated pages
        # even if the main language page is unpublished

        response = self.client.get('/locale/fr/')
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/"'
            ' class="section-listing__theme-bg-link">English section</a>')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2-in-french/"'
            ' class="section-listing__theme-bg-link">'
            'English section2 in french</a>')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/'
            'english-article1-in-french/"'
            ' class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-bg">'
            '<h3 class="heading'
            ' promoted-article-list__heading">'
            'English article1 in french</h3>', html=True)
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2/'
            'english-article1-in-section-2/" '
            'class="promoted-article-list__anchor'
            ' promoted-article-list__anchor--theme-bg">'
            '<h3 class="heading'
            ' promoted-article-list__heading">'
            'English article1 in section 2</h3></a>',
            html=True)

        response = self.client.get('/sections-main-1/english-section/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/'
            'english-article1-in-french/"'
            ' class="promoted-article-list__anchor">'
            '<h3 class="heading'
            ' promoted-article__title">English article1 in french</h3></a>',
            html=True)
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section/'
            'english-article2-in-french/"'
            ' class="promoted-article-list__anchor">'
            '<h3 class="heading'
            ' promoted-article__title">English article2 in french</h3></a>',
            html=True)

    def test_if_mexican_spanish_translated_pages_are_shown_on_front_end(self):
        en_section2 = self.mk_section(
            self.section_index, title='English section2')
        self.mk_section_translation(
            en_section2, self.spanish_mexico,
            title=en_section2.title + ' in Mexican Spanish')

        en_page = self.mk_article(
            en_section2,
            title='English article1',
            featured_in_latest_start_date=datetime.now(),
            featured_in_homepage_start_date=datetime.now())
        promote_articles()
        en_page = ArticlePage.objects.get(pk=en_page.pk)
        self.mk_article_translation(
            en_page, self.spanish_mexico,
            title=en_page.title + ' in Mexican Spanish',)

        response = self.client.get('/')
        self.assertContains(
            response,
            'English section2')
        self.assertNotContains(
            response,
            'English section2 in Mexican Spanish')

        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2/english-article1/" '
            'class="promoted-article-list__anchor '
            'promoted-article-list__anchor--theme-bg">'
            '<h3 class="heading'
            ' promoted-article-list__heading">'
            'English article1</h3></a>', html=True)
        self.assertNotContains(
            response,
            'English article1 in Mexican Spanish')

        response = self.client.get('/locale/es-mx/')
        response = self.client.get('/')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2-in-mexican-spanish/"'
            ' class="section-listing__theme-bg-link">'
            'English section2 in Mexican Spanish</a>')
        self.assertContains(
            response,
            '<a href="/sections-main-1/english-section2/'
            'english-article1-in-mexican-spanish/"'
            ' class="promoted-article-list__anchor '
            'promoted-article-list__anchor--theme-bg">'
            '<h3 class="heading'
            ' promoted-article-list__heading">'
            'English article1 in Mexican Spanish</h3></a>', html=True)



from __future__ import unicode_literals

from django.db import migrations, models


def create_section_index(apps, schema_editor):
    from molo.core.models import Main
    from molo.profiles.models import SecurityQuestionIndexPage
    main = Main.objects.all().first()
    index_page = SecurityQuestionIndexPage.objects.filter(
        slug='security-questions').first()

    if main and not index_page:
        index_page = SecurityQuestionIndexPage(
            title='Security Questions', slug='security-questions')
        main.add_child(instance=index_page)
        index_page.save_revision().publish()


class Migration(migrations.Migration):

    dependencies = [
        ('profiles', '0009_add_security_question_index_page'),
    ]

    operations = [
        migrations.RunPython(create_section_index),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-08-02 12:10
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0063_articlepagelanguageproxy'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitelanguage',
            name='locale',
            field=models.CharField(choices=[(b'af', b'Afrikaans'), (b'ar', b'Arabic'), (b'ast', b'Asturian'), (b'az', b'Azerbaijani'), (b'bg', b'Bulgarian'), (b'be', b'Belarusian'), (b'bn', b'Bengali'), (b'br', b'Breton'), (b'bs', b'Bosnian'), (b'ca', b'Catalan'), (b'cs', b'Czech'), (b'cy', b'Welsh'), (b'da', b'Danish'), (b'de', b'German'), (b'el', b'Greek'), (b'en', b'English'), (b'en-au', b'Australian English'), (b'en-gb', b'British English'), (b'eo', b'Esperanto'), (b'es', b'Spanish'), (b'es-ar', b'Argentinian Spanish'), (b'es-co', b'Colombian Spanish'), (b'es-mx', b'Mexican Spanish'), (b'es-ni', b'Nicaraguan Spanish'), (b'es-ve', b'Venezuelan Spanish'), (b'et', b'Estonian'), (b'eu', b'Basque'), (b'fa', b'Persian'), (b'fi', b'Finnish'), (b'fr', b'French'), (b'fy', b'Frisian'), (b'ga', b'Irish'), (b'gd', b'Scottish Gaelic'), (b'gl', b'Galician'), (b'he', b'Hebrew'), (b'hi', b'Hindi'), (b'hr', b'Croatian'), (b'hu', b'Hungarian'), (b'ia', b'Interlingua'), (b'id', b'Indonesian'), (b'io', b'Ido'), (b'is', b'Icelandic'), (b'it', b'Italian'), (b'ja', b'Japanese'), (b'ka', b'Georgian'), (b'kk', b'Kazakh'), (b'km', b'Khmer'), (b'kn', b'Kannada'), (b'ko', b'Korean'), (b'lb', b'Luxembourgish'), (b'lt', b'Lithuanian'), (b'lv', b'Latvian'), (b'mk', b'Macedonian'), (b'ml', b'Malayalam'), (b'mn', b'Mongolian'), (b'mr', b'Marathi'), (b'my', b'Burmese'), (b'nb', b'Norwegian Bokmal'), (b'ne', b'Nepali'), (b'nl', b'Dutch'), (b'nn', b'Norwegian Nynorsk'), (b'os', b'Ossetic'), (b'pa', b'Punjabi'), (b'pl', b'Polish'), (b'pt', b'Portuguese'), (b'pt-br', b'Brazilian Portuguese'), (b'ro', b'Romanian'), (b'ru', b'Russian'), (b'sk', b'Slovak'), (b'sl', b'Slovenian'), (b'sq', b'Albanian'), (b'sr', b'Serbian'), (b'sr-latn', b'Serbian Latin'), (b'sv', b'Swedish'), (b'sw', b'Swahili'), (b'ta', b'Tamil'), (b'te', b'Telugu'), (b'th', b'Thai'), (b'tr', b'Turkish'), (b'tt', b'Tatar'), (b'udm', b'Udmurt'), (b'uk', b'Ukrainian'), (b'ur', b'Urdu'), (b'vi', b'Vietnamese'), (b'zh-hans', b'Simplified Chinese'), (b'zh-hant', b'Traditional Chinese'), (b'zu', 'Zulu'), (b'xh', 'Xhosa'), (b'st', 'Sotho'), (b've', 'Venda'), (b'tn', 'Tswana'), (b'ts', 'Tsonga'), (b'ss', 'Swati'), (b'nr', 'Ndebele'), (b'bem', 'Bemba'), (b'nya', 'Nyanja'), (b'ny', 'Chichewa')], help_text='Site language', max_length=255, verbose_name='language name'),
        ),
    ]



from collections import OrderedDict

from rest_framework import serializers

from wagtail.api.v2.serializers import PageSerializer
from wagtail.wagtailimages.api.v2.serializers import ImageSerializer

from molo.core.models import TranslatablePageMixinNotRoutable, ImageInfo


class PageChildrenField(serializers.Field):
    """
    Serializes the "children" field.

    Example:
    "children": {
        "count": 1,
        "listing_url": "/api/v1/pages/?child_of=2"
    }
    """
    def get_attribute(self, instance):
        return instance

    def to_representation(self, page):
        if page.get_children():
            items = []
            for item in page.get_children():
                items.append(item.id)
            return OrderedDict([
                ("items", items),
            ])


class MainLanguageChildrenField(serializers.Field):
    """
    Serializes the "children" field with only children that belong
    to the main language.

    Example:
    "children": [12, 34]
    """
    def get_attribute(self, instance):
        return instance

    def to_representation(self, page):
        if page.get_children():
            return [child_page.id for child_page
                    in page.get_children()
                    if not hasattr(child_page.specific, 'source_page')]


class PageTranslationsField(serializers.Field):
    """
    Serializes the "translations" field.

    If the Page is translatable, it will return all of the translated
    versions of the page, including the main lanugage page. It will
    exclude the original page id from the list.

    Edge case: a translated version of a page may subsequenly have its
    language deleted, leaving the page. In this case, the locale field
    will display None.

    Example:
    "translations": [
        {
            "locale": "ve",
            "id": 24
        },
        {
            "locale": "fr",
            "id": 25
        }
    ]

    """
    def get_attribute(self, instance):
        return instance

    def to_representation(self, page):
        if isinstance(page.specific, TranslatablePageMixinNotRoutable):
            main_page = page.specific.get_main_language_page().specific
            items = []

            if page.specific == main_page:
                pages = [page_relation.translated_page.specific
                         for page_relation in main_page.translations.all()]
            else:
                pages = ([main_page] +
                         [page_relation.translated_page.specific
                         for page_relation in main_page.translations.all()
                         if page_relation.translated_page.id != page.id])

            for translated_page in pages:
                locale = None
                try:
                    locale = translated_page.languages.get().language.locale
                except:
                    pass

                items.append({
                    "id": translated_page.id,
                    "locale": locale
                })
            return items
        else:
            return None


class MoloPageSerializer(PageSerializer):
    children = PageChildrenField(read_only=True)
    translations = PageTranslationsField(read_only=True)
    main_language_children = MainLanguageChildrenField(read_only=True)


class ImageUrlField(serializers.Field):
    """
    Provides an accesible URL for image file
    """
    def get_attribute(self, instance):
        return instance

    def to_representation(self, image):
        rendition = image.get_rendition('original')
        return rendition.url


class ImageFileHashField(serializers.Field):
    """
    Provides an accesible URL for image file
    """
    def get_attribute(self, instance):
        return instance

    def to_representation(self, image):
        if not hasattr(image, 'image_info'):
            ImageInfo.objects.create(image=image)

        image.refresh_from_db()

        return image.image_info.image_hash


class MoloImageSerializer(ImageSerializer):
    image_url = ImageUrlField(read_only=True)
    image_hash = ImageFileHashField(read_only=True)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0005_add_nullable_to_articlepage_sectionpage'),
    ]

    operations = [
        migrations.AlterField(
            model_name='languagepage',
            name='code',
            field=models.CharField(help_text='The language code as specified in iso639-2', max_length=255),
            preserve_default=True,
        ),
    ]



import json
from .constants import (
    AVAILABLE_ARTICLES,
    AVAILABLE_SECTIONS,
    AVAILABLE_SECTION_CHILDREN,
    RELATED_IMAGE,
    ARTICLE_PAGE_RESPONSE,
    SECTION_PAGE_RESPONSE,
    WAGTAIL_API_LIST_VIEW_PAGE_1,
    WAGTAIL_API_LIST_VIEW_PAGE_2,
    TYPE_SECTION_INDEX_PAGE_RESPONSE,
    SECTION_INDEX_PAGE_RESPONSE,
    SECTION_RESPONSE_1,
    SECTION_RESPONSE_1_TRANSLATION_1,
    ARTICLE_RESPONSE_1,
    ARTICLE_RESPONSE_1_TRANSLATION,
    ARTICLE_RESPONSE_2,
    SECTION_RESPONSE_2,
    SUB_SECTION_RESPONSE_1,
    NESTED_ARTICLE_RESPONSE,
)
from wagtail.wagtailimages.tests.utils import get_test_image_file
from wagtail.wagtailimages.models import Image


# Inspired by http://stackoverflow.com/a/28507806
def mocked_requests_get(url, *args, **kwargs):
    """ This object will be used to mock requests.get() """
    class MockResponse:
        def __init__(self, content, status_code):
            self.content = content
            self.status_code = status_code

        def content(self):
            return self.content

        def json(self):
            return self.content

    if url == "http://localhost:8000/api/v2/pages/":
        return MockResponse(AVAILABLE_ARTICLES, 200)
    elif url == "http://localhost:8000/api/v2/images/1/":
        return MockResponse(RELATED_IMAGE, 200)
    elif url == "http://localhost:8000/api/v2/pages/?child_of=2":
        return MockResponse(AVAILABLE_SECTION_CHILDREN, 200)
    # Responses for individual section page requests
    elif url == "http://localhost:8000/api/v2/pages/2/":
        return MockResponse(AVAILABLE_SECTIONS["items"][0], 200)
    elif url == "http://localhost:8000/api/v2/pages/3/":
        return MockResponse(AVAILABLE_SECTIONS["items"][1], 200)
    elif url == "http://localhost:8000/api/v2/pages/4/":
        return MockResponse(AVAILABLE_SECTIONS["items"][2], 200)

    # Responses for individual article page requests
    elif url == "http://localhost:8000/api/v2/pages/10/":
        return MockResponse(AVAILABLE_ARTICLES["items"][0], 200)
    elif url == "http://localhost:8000/api/v2/pages/11/":
        return MockResponse(AVAILABLE_ARTICLES["items"][1], 200)
    elif url == "http://localhost:8000/api/v2/pages/12/":
        return MockResponse(AVAILABLE_ARTICLES["items"][2], 200)
    elif url == "http://localhost:8000/api/v2/pages/?type=core.ArticlePage" \
                "&fields=title,subtitle,body,tags,commenting_state," \
                "commenting_open_time,commenting_close_time," \
                "social_media_title,social_media_description," \
                "social_media_image,related_sections," \
                "featured_in_latest,featured_in_latest_start_date" \
                ",featured_in_latest_end_date,featured_in_section," \
                "featured_in_section_start_date," \
                "featured_in_section_end_date" \
                ",featured_in_homepage,featured_in_homepage_start_date" \
                ",featured_in_homepage_end_date,feature_as_topic_of_the_day" \
                ",promote_date,demote_date,metadata_tags," \
                "latest_revision_created_at," \
                "image,social_media_image,social_media_description," \
                "social_media_title&order=latest_revision_created_at":
        return MockResponse(AVAILABLE_ARTICLES, 200)
    elif url == "http://localhost:8000/api/v2/images/":
        return MockResponse(json.dumps(WAGTAIL_API_LIST_VIEW_PAGE_1), 200)
    elif url == "http://localhost:8000/api/v2/images/?limit=20&offset=20":
        return MockResponse(json.dumps(WAGTAIL_API_LIST_VIEW_PAGE_2), 200)
    elif url == "http://localhost:8000/media/images/SIbomiWV1AQ.original.jpg":
        return MockResponse(get_test_image_file().__str__(), 200)
    elif url == "http://localhost:8000/api/v2/pages/?type=core.SectionIndexPage":  # noqa
        return MockResponse(
            json.dumps(TYPE_SECTION_INDEX_PAGE_RESPONSE),
            200)
    elif url == "http://localhost:8000/api/v2/pages/6/":
        return MockResponse(json.dumps(SECTION_INDEX_PAGE_RESPONSE), 200)
    elif url == "http://localhost:8000/api/v2/pages/178/":
        return MockResponse(json.dumps(SECTION_RESPONSE_1), 200)
    elif url == "http://localhost:8000/api/v2/pages/180/":
        return MockResponse(json.dumps(SECTION_RESPONSE_1_TRANSLATION_1), 200)
    elif url == "http://localhost:8000/api/v2/pages/181/":
        return MockResponse(json.dumps(ARTICLE_RESPONSE_1), 200)
    elif url == "http://localhost:8000/api/v2/pages/183/":
        return MockResponse(json.dumps(ARTICLE_RESPONSE_1_TRANSLATION), 200)
    elif url == "http://localhost:8000/api/v2/pages/182/":
        return MockResponse(json.dumps(ARTICLE_RESPONSE_2), 200)
    elif url == "http://localhost:8000/api/v2/pages/179/":
        return MockResponse(json.dumps(SECTION_RESPONSE_2), 200)
    elif url == "http://localhost:8000/api/v2/pages/184/":
        return MockResponse(json.dumps(SUB_SECTION_RESPONSE_1), 200)
    elif url == "http://localhost:8000/api/v2/pages/185/":
        return MockResponse(json.dumps(NESTED_ARTICLE_RESPONSE), 200)

    return MockResponse({}, 404)


def mocked_fetch_and_create_image(url, image_title):
    image = Image.objects.create(
        title=image_title,
        file=get_test_image_file(),
    )
    context = {
        "file_url": url,
        "foreign_title": image_title,
    }
    return (image, context)


def fake_article_page_response(**kwargs):
    '''
    Returns a fully featured article with all the
    bells and whistles.

    Pass in kwargs to suppress certain elements
    '''
    response = dict(ARTICLE_PAGE_RESPONSE)
    response.update(kwargs)
    return response


def fake_section_page_response(**kwargs):
    '''
    Returns a fully featured article with all the
    bells and whistles.

    Pass in kwargs to suppress certain elements
    '''
    response = dict(SECTION_PAGE_RESPONSE)
    response.update(kwargs)
    return response



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0034_create_index_pages'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='content_rotation',
            field=models.BooleanField(default=False, help_text='This option allows content to be rotated randomly and automatically'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='content_rotation_time',
            field=models.IntegerField(blank=True, help_text='This is the time that content will be rotated every day. If the content should rotate at 14h, then fill in 14', null=True, validators=[django.core.validators.MaxValueValidator(23), django.core.validators.MinValueValidator(0)]),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2017-09-26 09:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0032_add_bulk_delete_page_permission'),
        ('profiles', '0017_userprofile_migrated_username'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='admin_sites',
            field=models.ManyToManyField(related_name='admin_sites', to='wagtailcore.Site'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import modelcluster.contrib.taggit


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0021_add-meta-tags-field-to-article-page'),
    ]

    operations = [
        migrations.AlterField(
            model_name='articlepage',
            name='metadata_tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(to='taggit.Tag', through='core.ArticlePageMetaDataTag', blank=True, help_text='A comma-separated list of tags. This is not visible to the user.', verbose_name='Tags'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.12 on 2017-03-08 14:17
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0032_add_bulk_delete_page_permission'),
        ('profiles', '0013_add_location_gender_education_level_fields'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprofile',
            name='site',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site'),
        ),
    ]



import json
from datetime import datetime

from django.contrib.auth import get_user_model
from django.contrib.contenttypes.models import ContentType

from wagtail.wagtailcore.models import Page, Collection

from molo.core.models import (Main, SectionPage, ArticlePage, PageTranslation,
                              SectionIndexPage, FooterIndexPage,
                              BannerIndexPage, TagIndexPage, Tag,
                              ReactionQuestionIndexPage,
                              ArticlePageReactionQuestions, ReactionQuestion,
                              ReactionQuestionChoice, BannerPage)
from molo.core.utils import generate_slug


class MoloTestCaseMixin(object):
    def login(self):
        # Create a user
        user = get_user_model().objects.create_superuser(
            username='superuser', email='superuser@email.com', password='pass')

        # Login
        self.client.login(username='superuser', password='pass')

        return user

    def mk_root(self):
        page_content_type, created = ContentType.objects.get_or_create(
            model='page',
            app_label='wagtailcore'
        )
        self.root, _ = Page.objects.get_or_create(
            title="Root",
            slug='root',
            content_type=page_content_type,
            path='0001',
            depth=1,
            numchild=1,
            url_path='/',
        )

    def mk_main(self, title='Main', slug='main'):
        self.mk_root()
        main_content_type, created = ContentType.objects.get_or_create(
            model='main', app_label='core')

        # Create a new homepage
        self.main = Main.objects.create(
            title=title,
            slug=slug,
            content_type=main_content_type,
            path='00010001',
            depth=2,
            numchild=0,
            url_path='/home/',
        )
        self.main.save_revision().publish()
        self.main.save()

        # Create index pages
        self.section_index = SectionIndexPage.objects.child_of(
            self.main).first()

        self.reaction_index = ReactionQuestionIndexPage.objects.child_of(
            self.main).first()

        self.footer_index = FooterIndexPage.objects.child_of(self.main).first()

        self.banner_index = BannerIndexPage.objects.child_of(self.main).first()

        self.tag_index = TagIndexPage.objects.child_of(self.main).first()

        # Create root collection
        Collection.objects.create(
            name="Root",
            path='0001',
            depth=1,
            numchild=0,
        )
        # Create a site with the new homepage set as the root
        # Site.objects.all().delete()
        self.site = self.main.get_site()

    def mk_main2(self, title='main2', slug='main2', path='4098'):
        self.mk_root()
        main_content_type, created = ContentType.objects.get_or_create(
            model='main', app_label='core')

        # Create a new homepage
        self.main2 = Main.objects.create(
            title=title,
            slug=slug,
            content_type=main_content_type,
            path=path,
            depth=2,
            numchild=0,
            url_path='/main2/',
        )
        self.main2.save_revision().publish()
        self.main2.save()

        # Create index pages
        self.section_index2 = SectionIndexPage.objects.child_of(
            self.main2).first()

        self.reaction_index2 = ReactionQuestionIndexPage.objects.child_of(
            self.main2).first()

        self.footer_index2 = FooterIndexPage.objects.child_of(
            self.main2).first()

        self.banner_index2 = BannerIndexPage.objects.child_of(
            self.main2).first()

        self.tag_index2 = TagIndexPage.objects.child_of(
            self.main2).first()

        # Create root collection
        Collection.objects.get_or_create(
            name="Root",
            path='0001',
            depth=1,
            numchild=0,
        )

        # Create a site with the new homepage set as the root
        # Site.objects.all().delete()
        self.site2 = self.main2.get_site()

    def mk_main3(self, title='main3', slug='main3', path='4099'):
        self.mk_root()
        main_content_type, created = ContentType.objects.get_or_create(
            model='main', app_label='core')

        # Create a new homepage
        self.main3 = Main.objects.create(
            title=title,
            slug=slug,
            content_type=main_content_type,
            path=path,
            depth=2,
            numchild=0,
            url_path='/main3/',
        )
        self.main3.save_revision().publish()
        self.main3.save()

        # Create index pages
        self.section_index3 = SectionIndexPage.objects.child_of(
            self.main3).first()

        self.reaction_index3 = ReactionQuestionIndexPage.objects.child_of(
            self.main3).first()

        self.footer_index3 = FooterIndexPage.objects.child_of(
            self.main3).first()

        self.banner_index3 = BannerIndexPage.objects.child_of(
            self.main3).first()

        self.tag_index3 = TagIndexPage.objects.child_of(
            self.main3).first()

        # Create root collection
        Collection.objects.get_or_create(
            name="Root",
            path='0001',
            depth=1,
            numchild=0,
        )

        # Create a site with the new homepage set as the root
        # Site.objects.all().delete()
        self.site3 = self.main3.get_site()

    def mk_tag(self, parent, slug=None, **kwargs):
        data = {}
        data.update({
            'title': 'Test Tag',
        })
        data.update(kwargs)
        if slug:
            data.update({'slug': slug})
        else:
            data.update({'slug': generate_slug(data['title'])})
        tag = Tag(**data)
        parent.add_child(instance=tag)
        tag.save_revision().publish()
        return tag

    def mk_tags(self, parent, count=2, **kwargs):
        tags = []
        for i in range(count):
            data = {}
            data.update({
                'title': 'Test Tag {}'.format(i),
            })
            data.update(kwargs)
            data.update({
                'slug': generate_slug(data['title'])
            })
            tag = Tag(**data)
            parent.add_child(instance=tag)
            tag.save_revision().publish()
            tags.append(tag)
        return tags

    def mk_reaction_question(self, parent, article, **kwargs):
        data = {}
        data.update({
            'title': 'Test Question',
        })
        data.update(kwargs)
        data.update({
            'slug': generate_slug(data['title'])
        })
        question = ReactionQuestion(**data)
        parent.add_child(instance=question)
        question.save_revision().publish()
        choice1 = ReactionQuestionChoice(
            title='yes', success_message='well done')
        question.add_child(instance=choice1)
        choice1.save_revision().publish()
        choice2 = ReactionQuestionChoice(title='maybe')
        question.add_child(instance=choice2)
        choice2.save_revision().publish()
        choice3 = ReactionQuestionChoice(title='no')
        question.add_child(instance=choice3)
        choice3.save_revision().publish()
        ArticlePageReactionQuestions.objects.create(
            reaction_question=question, page=article)
        return question

    def mk_sections(self, parent, count=2, **kwargs):
        sections = []
        for i in range(count):
            data = {}
            data.update({
                'title': 'Test Section %s' % (i, ),
            })
            data.update(kwargs)
            data.update({
                'slug': generate_slug(data['title']),
            })
            section = SectionPage(**data)
            parent.add_child(instance=section)
            section.save_revision().publish()
            sections.append(section)
        return sections

    def mk_articles(self, parent, count=2, **kwargs):
        articles = []

        for i in range(count):
            data = {}
            data.update({
                'title': 'Test page %s' % (i, ),
                'subtitle': 'Sample page description for %s' % (i, ),
                'body': json.dumps([{
                    'type': 'paragraph',
                    'value': 'Sample page content for %s' % (i, )}]),
            })
            data.update(kwargs)
            data.update({
                'slug': generate_slug(data['title'])
            })
            article = ArticlePage(**data)
            if not article.first_published_at:
                article.first_published_at = datetime.now()
            parent.add_child(instance=article)
            article.save_revision().publish()
            articles.append(article)
        return articles

    def mk_banners(self, parent, count=2, **kwargs):
        banners = []
        for i in range(count):
            data = {}
            data.update({
                'title': 'Test Banner {}'.format(i),
            })
            data.update(kwargs)
            data.update({
                'slug': generate_slug(data['title'])
            })
            banner = BannerPage(**data)
            parent.add_child(instance=banner)
            banner.save_revision().publish()
            banners.append(banner)
        return banners

    def mk_section(self, parent, **kwargs):
        return self.mk_sections(parent, count=1, **kwargs)[0]

    def mk_article(self, parent, **kwargs):
        return self.mk_articles(parent, count=1, **kwargs)[0]

    def mk_banner(self, parent, **kwargs):
        return self.mk_banners(parent, count=1, **kwargs)[0]

    def mk_translation(self, source, language, translation):
        language_relation = translation.languages.first()
        language_relation.language = language
        language_relation.save()
        translation.language = language
        translation.save_revision().publish()
        source.specific.translated_pages.add(translation)
        source.save()
        PageTranslation.objects.get_or_create(
            page=source, translated_page=translation)
        for translated_page in \
                source.specific.translated_pages.all():
            translations = source.specific.translated_pages.all().\
                exclude(language__pk=translated_page.language.pk)
            for t in translations:
                translated_page.translated_pages.add(t)
            translated_page.save()
        return translation

    def mk_section_translation(self, source, language, **kwargs):
        instance = self.mk_section(source.get_parent(), **kwargs)
        return self.mk_translation(source, language, instance)

    def mk_article_translation(self, source, language, **kwargs):
        instance = self.mk_article(source.get_parent(), **kwargs)
        return self.mk_translation(source, language, instance)

    def mk_tag_translation(self, source, language, **kwargs):
        instance = self.mk_tag(source.get_parent(), **kwargs)
        return self.mk_translation(source, language, instance)

    def mk_reaction_translation(self, source, article, language, **kwargs):
        instance = self.mk_reaction_question(
            source.get_parent(), article, **kwargs)
        return self.mk_translation(source, language, instance)



# -*- coding: utf-8 -*-

import responses
import mock
from django.test import TestCase
from django.test.client import Client
from django.test.client import RequestFactory
from django.contrib.sessions.middleware import SessionMiddleware
from django.core.urlresolvers import reverse

from google_analytics.templatetags.google_analytics_tags import google_analytics  # noqa
from molo.core.middleware import MoloGoogleAnalyticsMiddleware
from molo.core.models import Main, Languages, SiteLanguageRelation
from molo.core.tests.base import MoloTestCaseMixin
from wagtail.wagtailsearch.backends import get_search_backend


class TestUtils(TestCase, MoloTestCaseMixin):

    def setUp(self):
        self.client = Client()
        # Creates Main language
        self.mk_main()
        main = Main.objects.all().first()
        self.english = SiteLanguageRelation.objects.create(
            language_setting=Languages.for_site(main.get_site()),
            locale='en',
            is_active=True)
        # Creates a section under the index page
        self.english_section = self.mk_section(
            self.section_index, title='English section')

    def make_fake_request(self, url, headers={}):
        """
        We don't have any normal views, so we're creating fake
        views using django's RequestFactory
        """
        rf = RequestFactory()
        request = rf.get(url, **headers)
        session_middleware = SessionMiddleware()
        session_middleware.process_request(request)
        request.session.save()
        return request

    @responses.activate
    @mock.patch("google_analytics.utils.build_ga_params")
    def test_ga_middleware(self, mock_method):
        self.backend = get_search_backend('default')
        self.backend.reset_index()
        self.mk_articles(self.english_section, count=2)
        self.backend.refresh_index()
        response = self.client.get(reverse('search'), {
            'q': 'Test'
        })
        headers = {'HTTP_X_IORG_FBS_UIP': '100.100.200.10'}
        request = self.make_fake_request(
            '/search/?q=Test', headers)

        middleware = MoloGoogleAnalyticsMiddleware()
        account = ''
        response = middleware.submit_tracking(account, request, response)

        self.assertTrue(mock_method.called_with(request.get_full_path()))

    @mock.patch("google_analytics.utils.build_ga_params")
    def test_ga_submit_tracking_with_custom_params(self, mock_method):
        self.backend = get_search_backend('default')
        self.backend.reset_index()
        self.mk_articles(self.english_section, count=2)
        self.backend.refresh_index()
        response = self.client.get(reverse('search'), {
            'q': 'Test'
        })
        headers = {'HTTP_X_IORG_FBS_UIP': '100.100.200.10'}
        request = self.make_fake_request(
            '/search/?q=Test', headers)

        middleware = MoloGoogleAnalyticsMiddleware()
        account = ''
        custom_params = {'cd2': '1235-245'}
        response = middleware.submit_tracking(account,
                                              request,
                                              response,
                                              custom_params,
                                              )
        self.assertTrue(mock_method.called_with(custom_params))



# -*- coding: utf-8 -*-
# Generated by Django 1.9.11 on 2016-11-14 13:52
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import wagtail.wagtailcore.blocks
import wagtail.wagtailcore.fields
import wagtail.wagtailimages.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0012_copy_image_permissions_to_collections'),
        ('core', '0048_promotion_dates'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitesettings',
            name='facebook_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='facebook_sharing',
            field=models.BooleanField(default=False, help_text=b'Enable this field to allow for sharing to Facebook.', verbose_name=b'Facebook'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='social_media_links_on_footer_page',
            field=wagtail.wagtailcore.fields.StreamField([(b'social_media_site', wagtail.wagtailcore.blocks.StructBlock([(b'title', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'link', wagtail.wagtailcore.blocks.CharBlock(required=True)), (b'image', wagtail.wagtailimages.blocks.ImageChooserBlock())]))], blank=True, null=True),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='twitter_image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
        migrations.AddField(
            model_name='sitesettings',
            name='twitter_sharing',
            field=models.BooleanField(default=False, help_text=b'Enable this field to allow for sharing to Twitter.', verbose_name=b'Twitter'),
        ),
    ]
